<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Fox009_Vermilion
 */
if( ! function_exists( 'fox009_vermilion_body_classes' ) ) {
	function fox009_vermilion_body_classes( $classes ) {
		// Adds a class of hfeed to non-singular pages.
		if ( ! is_singular() ) {
			$classes[] = 'hfeed';
		}

		$classes[] = 'sidebar-' . fox009_vermilion_sidebar_layout();
		$classes[] = 'thumbnail-' . fox009_vermilion_theme_options('thumbnail_position');

		return $classes;
	}
}
add_filter( 'body_class', 'fox009_vermilion_body_classes' );

if( ! function_exists( 'fox009_vermilion_sidebar_layout' ) ) {	
	function fox009_vermilion_sidebar_layout(){
		$sidebar_layout = 'default';
		if(is_home() || is_archive() || is_search()){
			$sidebar_layout = fox009_vermilion_theme_options('sidebar_layout_archive');
		}else if(is_single()){
			$sidebar_layout = fox009_vermilion_theme_options('sidebar_layout_single');
		}else if(is_page()){
			$sidebar_layout = fox009_vermilion_theme_options('sidebar_layout_page');
		}
		
		if($sidebar_layout == 'default'){
			$sidebar_layout = fox009_vermilion_theme_options('default_sidebar_layout');
		}
		return $sidebar_layout;
	}
}

if( ! function_exists( 'fox009_vermilion_pingback_header' ) ) {
	function fox009_vermilion_pingback_header() {
		if ( is_singular() && pings_open() ) {
			printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
		}
	}
}
add_action( 'wp_head', 'fox009_vermilion_pingback_header' );

if( ! function_exists( 'fox009_vermilion_default_theme_options' ) ) {
	function fox009_vermilion_default_theme_options(){
        $defaults = array(
			'container_layout'				=> 'limit',
			'container_max_width'			=> 1240,
			'primary_color'           		=> '#cb2821',
			'default_sidebar_layout'		=> 'right',
			'sidebar_layout_archive'		=> 'default',
			'sidebar_layout_single'			=> 'default',
			'sidebar_layout_page'			=> 'default',
			'sidebar_width'					=> 30,
			'enable_breadcrumbs'			=> 1,
			'disable_breadcrumbs_home'		=> 1,
			'disable_breadcrumbs_archive'	=> 0,
			'disable_breadcrumbs_search'	=> 1,
			'disable_breadcrumbs_single' 	=> 0,
			'disable_breadcrumbs_page'		=> 1,
			'disable_breadcrumbs_404'		=> 1,
			'breadcrumbs_separator'			=> '/',
			'button_color'					=> '#ffffff',
			'button_border_radius'			=> 4,
            'header_top_section' 			=> 1,
            'header_top_menu'         		=> 1,				
			'header_social'					=> 1,
			'site_title_font_size'			=> 3,
			'header_nav_transform'			=> 'uppercase',
			'top_nav_padding_left'			=> 20,
			'main_nav_padding_left'			=> 20,
			'top_menu_text'					=> esc_html__('Secondary Menu', 'fox009-vermilion'),
			'main_menu_text'				=> esc_html__('Primary Menu', 'fox009-vermilion'),
			'enable_slider'					=> 1,
			'slider_category'             	=> 0,
			'slider_images_count'			=> 5,
			'slider_max_height'				=> 500,
			'slider_autoplay_timeout'		=> 5000,
			'slider_background_color'  		=> '#ffffff',
			'slider_autoplay'				=> 0,
			'slider_loop'					=> 0,
			'thumbnail_position'        	=> 'left',		
            'archive_excerpt_length'    	=> 100,
            'archive_read_more'         	=> esc_html__('Read More', 'fox009-vermilion'),	
			'archive_post_first'			=> 'title',
			'archive_post_second'			=> 'meta',
			'archive_meta_first'			=> 'auther',
			'archive_meta_second'			=> 'categories',
			'archive_meta_third'			=> 'date',
			'archive_meta_fourth'			=> 'comments',
			'enable_featured_image'			=> 1,
			'enable_post_tags'				=> 1,
			'single_post_first'				=> 'title',
			'single_post_second'			=> 'meta',
			'single_meta_first'				=> 'auther',
			'single_meta_second'			=> 'categories',
			'single_meta_third'				=> 'date',
			'single_meta_fourth'			=> 'comments',
			'custom_copyright_text'     	=> sprintf(
													/* translators: 1: copyright year, 2: blogname. */
													__('&copy; Copyright %1$s %2$s All Rights Reserved.', 'fox009-vermilion'),
													date_i18n(esc_html__('Y', 'fox009-vermilion')),
													'<a href="' . esc_url(home_url('/')) . '">'. 
													esc_html(get_bloginfo('name')) . '</a>'
												),			

			
							
			/*


            'sticky_sidebar'    => 'enable',

            

            'show_archive_auther'       => 1,
            'show_archive_category'     => 1,
            'show_archive_date'         => 1,
            'show_archive_comment'      => 1,

            'show_single_realted_post'      => 'enable',
            'single_realted_post_title'     => esc_html__('Related Posts', 'fox009-vermilion'),
            'show_single_auther'       => 1,
            'show_single_category'     => 1,
            'show_single_date'         => 1,
            'show_single_comment'      => 1,
                                            )
			*/
        ); 
		return $defaults;
	}
}

if( ! function_exists( 'fox009_vermilion_theme_options' ) ) {
	function fox009_vermilion_theme_options($key) {
		//fox009_vermilion_default_theme_options
		return get_theme_mod('fox009_vermilion_' . $key, fox009_vermilion_default_theme_options()[$key]);
	}
}

if( ! function_exists( 'fox009_vermilion_menu_fallback' ) ) {
	function fox009_vermilion_menu_fallback($args){
		if ( current_user_can( 'edit_theme_options' ) ) {	
			$container       = $args['container'];
			$container_id    = $args['container_id'];
			$container_class = $args['container_class'];
			$menu_class      = $args['menu_class'];
			$menu_id         = $args['menu_id'];

			$menu_html = '';
			
			if ( $container ) {
				$menu_html .= '<' . esc_attr( $container );
				if ( $container_id ) {
					$menu_html .= ' id="' . esc_attr( $container_id ) . '"';
				}
				if ( $container_class ) {
					$menu_html .= ' class="' . esc_attr( $container_class ) . '"';
				}
				$menu_html .= '>';
			}
			
			$menu_html .= '<ul';
			if ( $menu_id ) {
				$menu_html .= ' id="' . esc_attr( $menu_id ) . '"'; }
			if ( $menu_class ) {
				$menu_html .= ' class="' . esc_attr( $menu_class ) . '"'; }
			$menu_html .= '>';
			
			$menu_html .= '<li><a href="' . esc_url( admin_url( 'nav-menus.php?action=locations' ) ) . '">' . esc_html__( 'Click to set menu', 'fox009-vermilion' ) . '</a></li>';
			
			$menu_html .= '</ul>';
			
			if ( $container ) {
				$menu_html .= '</' . esc_attr( $container ) . '>';
			}
			
			if ( array_key_exists( 'echo', $args ) && $args['echo'] ) {
				echo $menu_html;
			} else {
				return $menu_html;
			}
		}
	}
}

if( ! function_exists( 'fox009_vermilion_posts_navigation' ) ) {
	function fox009_vermilion_posts_navigation(){
		if($GLOBALS['wp_query']->max_num_pages>1){
		?>
			<div class="posts-navigation-container">			
				<?php 
				the_posts_pagination(
					array(
						'prev_text'          => __( 'Previous', 'fox009-vermilion' ),
						'next_text'          => __( 'Next', 'fox009-vermilion' ),
						'before_page_number' => '<span class="screen-reader-text">' . __( 'Page', 'fox009-vermilion' ) . ' </span>',
						'mid_size' => 2
					)
				);
				?>				
			</div>
		<?php
		}
	}
}

if( ! function_exists( 'fox009_vermilion_post_navigation' ) ) {
	function fox009_vermilion_post_navigation(){
	?>
		<div class="post-navigation-container padding20 shadow">
			<?php
			the_post_navigation(
				array(
					'prev_text' => '<span class="nav-subtitle">' . esc_html__( 'Previous:', 'fox009-vermilion' ) . '</span> <span class="nav-title">%title</span>',
					'next_text' => '<span class="nav-title">%title</span> <span class="nav-subtitle">' . esc_html__( ':Next', 'fox009-vermilion' ) . '</span>',
				)
			);
			?>
		</div>
	<?php
	}
}

if( ! function_exists( 'fox009_vermilion_post_structure' ) ) {
	function fox009_vermilion_post_structure(){
		$prefix = (is_single() || is_page()) ? 'single_' : 'archive_';
		$post_block = array(
			fox009_vermilion_theme_options($prefix . 'post_first'),
			fox009_vermilion_theme_options($prefix . 'post_second'),
		);
		foreach($post_block as $item){
			switch($item){
				case 'title':
					?>
						<h2 class="post-title">
							<a href="<?php the_permalink(); ?>">
								<?php the_title(); ?>
							</a>
						</h2>
					<?php
					break;
				case 'meta':
					?>
					<div class="post-meta">
						<?php
						$post_meta = array(
							fox009_vermilion_theme_options($prefix . 'meta_first'),
							fox009_vermilion_theme_options($prefix . 'meta_second'),
							fox009_vermilion_theme_options($prefix . 'meta_third'),
							fox009_vermilion_theme_options($prefix . 'meta_fourth'),
						);
						foreach($post_meta as $item){
							switch($item){
								case 'auther':
									fox009_vermilion_post_author(); 
									break;
								case 'categories':
									fox009_vermilion_post_categories();
									break;
								case 'date':
									fox009_vermilion_post_date();
									break;
								case 'comments':
									fox009_vermilion_post_comment_number();
									break;
							}
						}
						?>
					</div>
					<?php
					break;
			}
		}
	}
}