<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Fox009_Vermilion
 */

if ( ! function_exists( 'fox009_vermilion_post_date' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function fox009_vermilion_post_date() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		echo '<span class="meta-span post-date"><i class="fa fa-calendar"></i>' . $time_string . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'fox009_vermilion_post_author' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function fox009_vermilion_post_author() {
		$post_author = '<a class="author-link" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>';

		echo '<span class="meta-span post-author"><i class="fa fa-user"></i></i>' . $post_author . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'fox009_vermilion_post_categories' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function fox009_vermilion_post_categories() {
        $categories = get_the_category();
        if ( ! empty( $categories ) ) {
			$post_categories = '';
			foreach($categories as $category){
				$post_categories .='<a href="'.esc_url( get_category_link( $category->term_id ) ).'"rel="category" class="cat-link">'.esc_html( $category->name ).'</a>';
			}
			echo '<span class="meta-span post-categories"><i class="fa fa-folder"></i>' . $post_categories . '</span>';
        }
	}
endif;

if ( ! function_exists( 'fox009_vermilion_post_comment_number' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function fox009_vermilion_post_comment_number() {
		$post_comment_number = '<a class="comment-link" href="' . get_permalink() . 
		'#comments">' . get_comments_number_text( '(0)', '(1)', '(%)' ) . '</a>';

		echo '<span class="meta-span post-comment-number"><i class="fa fa-comments"></i>' . $post_comment_number . '</span>'; 

	}
endif;

if ( ! function_exists( 'fox009_vermilion_post_tags' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function fox009_vermilion_post_tags() {
        $tags = get_the_tags();
        if ( ! empty( $tags ) ) {
			foreach($tags as $tag){
				$post_tags ='<a href="'.esc_url( get_tag_link( $tag->term_id ) ).'"rel="tag" class="tag-link">'.esc_html( $tag->name ).'</a>';
				echo '<span class="meta-span post-tag"><i class="fa fa-tag"></i>' . $post_tags . '</span>';
			}

        }
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;
